"""
Generated class for SubstancePolymer. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.Attachment import *
from fhirmodels.R4.BackboneElement import *
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.Resource import *
from fhirmodels.R4.SubstanceAmount import *


class StartingMaterial(FhirBaseModel):
    """Todo.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept material: Todo
    :param CodeableConcept type: Todo
    :param bool isDefining: Todo
    :param SubstanceAmount amount: Todo
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "material": {"class_name": "CodeableConcept", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "amount": {"class_name": "SubstanceAmount", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        material: "CodeableConcept" = None,
        type: "CodeableConcept" = None,
        isDefining: "bool" = None,
        amount: "SubstanceAmount" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.material = material
        self.type = type
        self.isDefining = isDefining
        self.amount = amount

    @classmethod
    def from_dict(cls, data: dict) -> "SubstancePolymer":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstancePolymer":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class MonomerSet(FhirBaseModel):
    """Todo.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept ratioType: Todo
    :param StartingMaterial startingMaterial: Todo
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "ratioType": {"class_name": "CodeableConcept", "is_contained": False},
        "startingMaterial": {"class_name": "StartingMaterial", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        ratioType: "CodeableConcept" = None,
        startingMaterial: list["StartingMaterial"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.ratioType = ratioType
        self.startingMaterial = startingMaterial or []

    @classmethod
    def from_dict(cls, data: dict) -> "SubstancePolymer":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstancePolymer":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class DegreeOfPolymerisation(FhirBaseModel):
    """Todo.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept degree: Todo
    :param SubstanceAmount amount: Todo
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "degree": {"class_name": "CodeableConcept", "is_contained": False},
        "amount": {"class_name": "SubstanceAmount", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        degree: "CodeableConcept" = None,
        amount: "SubstanceAmount" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.degree = degree
        self.amount = amount

    @classmethod
    def from_dict(cls, data: dict) -> "SubstancePolymer":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstancePolymer":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class StructuralRepresentation(FhirBaseModel):
    """Todo.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Todo
    :param str representation: Todo
    :param Attachment attachment: Todo
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "attachment": {"class_name": "Attachment", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        representation: "str" = None,
        attachment: "Attachment" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.representation = representation
        self.attachment = attachment

    @classmethod
    def from_dict(cls, data: dict) -> "SubstancePolymer":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstancePolymer":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class RepeatUnit(FhirBaseModel):
    """Todo.:param CodeableConcept repeatUnitAmountType: Todo
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept orientationOfPolymerisation: Todo
    :param str repeatUnit: Todo
    :param SubstanceAmount amount: Todo
    :param DegreeOfPolymerisation degreeOfPolymerisation: Todo
    :param StructuralRepresentation structuralRepresentation: Todo
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "repeatUnitAmountType": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "orientationOfPolymerisation": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "amount": {"class_name": "SubstanceAmount", "is_contained": False},
        "degreeOfPolymerisation": {
            "class_name": "DegreeOfPolymerisation",
            "is_contained": True,
        },
        "structuralRepresentation": {
            "class_name": "StructuralRepresentation",
            "is_contained": True,
        },
    }

    def __init__(
        self,
        repeatUnitAmountType: "CodeableConcept" = None,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        orientationOfPolymerisation: "CodeableConcept" = None,
        repeatUnit: "str" = None,
        amount: "SubstanceAmount" = None,
        degreeOfPolymerisation: list["DegreeOfPolymerisation"] = None,
        structuralRepresentation: list["StructuralRepresentation"] = None,
    ):
        self.repeatUnitAmountType = repeatUnitAmountType
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.orientationOfPolymerisation = orientationOfPolymerisation
        self.repeatUnit = repeatUnit
        self.amount = amount
        self.degreeOfPolymerisation = degreeOfPolymerisation or []
        self.structuralRepresentation = structuralRepresentation or []

    @classmethod
    def from_dict(cls, data: dict) -> "SubstancePolymer":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstancePolymer":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Repeat(FhirBaseModel):
    """Todo.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int numberOfUnits: Todo
    :param str averageMolecularFormula: Todo
    :param CodeableConcept repeatUnitAmountType: Todo
    :param RepeatUnit repeatUnit: Todo
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "repeatUnitAmountType": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "repeatUnit": {"class_name": "RepeatUnit", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        numberOfUnits: "int" = None,
        averageMolecularFormula: "str" = None,
        repeatUnitAmountType: "CodeableConcept" = None,
        repeatUnit: list["RepeatUnit"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.numberOfUnits = numberOfUnits
        self.averageMolecularFormula = averageMolecularFormula
        self.repeatUnitAmountType = repeatUnitAmountType
        self.repeatUnit = repeatUnit or []

    @classmethod
    def from_dict(cls, data: dict) -> "SubstancePolymer":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstancePolymer":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class SubstancePolymer(DomainResource):
    """Todo.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param CodeableConcept _class: Todo
    :param CodeableConcept geometry: Todo
    :param CodeableConcept copolymerConnectivity: Todo
    :param str modification: Todo
    :param MonomerSet monomerSet: Todo
    :param Repeat repeat: Todo
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "_class": {"class_name": "CodeableConcept", "is_contained": False},
        "geometry": {"class_name": "CodeableConcept", "is_contained": False},
        "copolymerConnectivity": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "monomerSet": {"class_name": "MonomerSet", "is_contained": True},
        "repeat": {"class_name": "Repeat", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        _class: "CodeableConcept" = None,
        geometry: "CodeableConcept" = None,
        copolymerConnectivity: list["CodeableConcept"] = None,
        modification: list["str"] = None,
        monomerSet: list["MonomerSet"] = None,
        repeat: list["Repeat"] = None,
    ):

        self.resourceType = "SubstancePolymer"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self._class = _class
        self.geometry = geometry
        self.copolymerConnectivity = copolymerConnectivity or []
        self.modification = modification or []
        self.monomerSet = monomerSet or []
        self.repeat = repeat or []

    @classmethod
    def from_dict(cls, data: dict) -> "SubstancePolymer":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstancePolymer":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Invoice. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.Annotation import *
from fhirmodels.R4.BackboneElement import *
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Identifier import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Money import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.Reference import *
from fhirmodels.R4.Resource import *


class Participant(FhirBaseModel):
    """Indicates who or what performed or participated in the charged service.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept role: Type of involvement in creation of this Invoice
    :param Reference actor: Individual who was involved
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "role": {"class_name": "CodeableConcept", "is_contained": False},
        "actor": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        role: "CodeableConcept" = None,
        actor: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.role = role
        self.actor = actor

    @classmethod
    def from_dict(cls, data: dict) -> "Invoice":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Invoice":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class PriceComponent(FhirBaseModel):
    """The price for a ChargeItem may be calculated as a base price with surcharges/deductions that apply in certain conditions. A ChargeItemDefinition resource that defines the prices, factors and conditions that apply to a billing code is currently under development. The priceComponent element can be used to offer transparency to the recipient of the Invoice as to how the prices have been calculated.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str type: base | surcharge | deduction | discount | tax | informational
    :param CodeableConcept code: Code identifying the specific component
    :param float factor: Factor used for calculating this component
    :param Money amount: Monetary amount associated with this component
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "amount": {"class_name": "Money", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "str" = None,
        code: "CodeableConcept" = None,
        factor: "float" = None,
        amount: "Money" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.code = code
        self.factor = factor
        self.amount = amount

    @classmethod
    def from_dict(cls, data: dict) -> "Invoice":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Invoice":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class LineItem(FhirBaseModel):
    """Each line item represents one charge for goods and services rendered. Details such as date, code and amount are found in the referenced ChargeItem resource.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int sequence: Sequence number of line item
    :param Reference chargeItemReference: Reference to ChargeItem containing details of this line item or an inline billing code
    :param CodeableConcept chargeItemCodeableConcept: Reference to ChargeItem containing details of this line item or an inline billing code
    :param PriceComponent priceComponent: Components of total line item price
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "chargeItemReference": {"class_name": "Reference", "is_contained": False},
        "chargeItemCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "priceComponent": {"class_name": "PriceComponent", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        sequence: "int" = None,
        chargeItemReference: "Reference" = None,
        chargeItemCodeableConcept: "CodeableConcept" = None,
        priceComponent: list["PriceComponent"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.sequence = sequence
        self.chargeItemReference = chargeItemReference
        self.chargeItemCodeableConcept = chargeItemCodeableConcept
        self.priceComponent = priceComponent or []

    @classmethod
    def from_dict(cls, data: dict) -> "Invoice":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Invoice":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Invoice(DomainResource):
    """Invoice containing collected ChargeItems from an Account with calculated individual and total price for Billing purpose.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Business Identifier for item
    :param str status: draft | issued | balanced | cancelled | entered-in-error
    :param str cancelledReason: Reason for cancellation of this Invoice
    :param CodeableConcept type: Type of Invoice
    :param Reference subject: Recipient(s) of goods and services
    :param Reference recipient: Recipient of this invoice
    :param str date: Invoice date / posting date
    :param Participant participant: Participant in creation of this Invoice
    :param Reference issuer: Issuing Organization of Invoice
    :param Reference account: Account that is being balanced
    :param LineItem lineItem: Line items of this Invoice
    :param TotalPriceComponent totalPriceComponent: Components of Invoice total
    :param Money totalNet: Net total of this Invoice
    :param Money totalGross: Gross total of this Invoice
    :param str paymentTerms: Payment details
    :param Annotation note: Comments made about the invoice
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "recipient": {"class_name": "Reference", "is_contained": False},
        "participant": {"class_name": "Participant", "is_contained": True},
        "issuer": {"class_name": "Reference", "is_contained": False},
        "account": {"class_name": "Reference", "is_contained": False},
        "lineItem": {"class_name": "LineItem", "is_contained": True},
        "totalPriceComponent": {
            "class_name": "TotalPriceComponent",
            "is_contained": True,
        },
        "totalNet": {"class_name": "Money", "is_contained": False},
        "totalGross": {"class_name": "Money", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        status: "str" = None,
        cancelledReason: "str" = None,
        type: "CodeableConcept" = None,
        subject: "Reference" = None,
        recipient: "Reference" = None,
        date: "str" = None,
        participant: list["Participant"] = None,
        issuer: "Reference" = None,
        account: "Reference" = None,
        lineItem: list["LineItem"] = None,
        totalPriceComponent: list["TotalPriceComponent"] = None,
        totalNet: "Money" = None,
        totalGross: "Money" = None,
        paymentTerms: "str" = None,
        note: list["Annotation"] = None,
    ):

        self.resourceType = "Invoice"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.status = status
        self.cancelledReason = cancelledReason
        self.type = type
        self.subject = subject
        self.recipient = recipient
        self.date = date
        self.participant = participant or []
        self.issuer = issuer
        self.account = account
        self.lineItem = lineItem or []
        self.totalPriceComponent = totalPriceComponent or []
        self.totalNet = totalNet
        self.totalGross = totalGross
        self.paymentTerms = paymentTerms
        self.note = note or []

    @classmethod
    def from_dict(cls, data: dict) -> "Invoice":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Invoice":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for ChargeItem. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.Annotation import *
from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Money import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Period import *
from fhirmodels.R4B.Quantity import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Resource import *
from fhirmodels.R4B.Timing import *


class Performer(FhirBaseModel):
    """Indicates who or what performed or participated in the charged service.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept function: What type of performance was done
    :param Reference actor: Individual who was performing
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "function": {"class_name": "CodeableConcept", "is_contained": False},
        "actor": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        function: "CodeableConcept" = None,
        actor: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.function = function
        self.actor = actor

    @classmethod
    def from_dict(cls, data: dict) -> "ChargeItem":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ChargeItem":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ChargeItem(DomainResource):
    """The resource ChargeItem describes the provision of healthcare provider products for a certain patient, therefore referring not only to the product, but containing in addition details of the provision, like date, time, amounts and participating organizations and persons. Main Usage of the ChargeItem is to enable the billing process and internal cost allocation.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Business Identifier for item
    :param str definitionUri: Defining information about the code of this charge item
    :param str definitionCanonical: Resource defining the code of this ChargeItem
    :param str status: planned | billable | not-billable | aborted | billed | entered-in-error | unknown
    :param Reference partOf: Part of referenced ChargeItem
    :param CodeableConcept code: A code that identifies the charge, like a billing code
    :param Reference subject: Individual service was done for/to
    :param Reference context: Encounter / Episode associated with event
    :param str occurrenceDateTime: When the charged service was applied
    :param Period occurrencePeriod: When the charged service was applied
    :param Timing occurrenceTiming: When the charged service was applied
    :param Performer performer: Who performed charged service
    :param Reference performingOrganization: Organization providing the charged service
    :param Reference requestingOrganization: Organization requesting the charged service
    :param Reference costCenter: Organization that has ownership of the (potential, future) revenue
    :param Quantity quantity: Quantity of which the charge item has been serviced
    :param CodeableConcept bodysite: Anatomical location, if relevant
    :param float factorOverride: Factor overriding the associated rules
    :param Money priceOverride: Price overriding the associated rules
    :param str overrideReason: Reason for overriding the list price/factor
    :param Reference enterer: Individual who was entering
    :param str enteredDate: Date the charge item was entered
    :param CodeableConcept reason: Why was the charged  service rendered?
    :param Reference service: Which rendered service is being charged?
    :param Reference productReference: Product charged
    :param CodeableConcept productCodeableConcept: Product charged
    :param Reference account: Account to place this charge
    :param Annotation note: Comments made about the ChargeItem
    :param Reference supportingInformation: Further information supporting this charge
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "partOf": {"class_name": "Reference", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "context": {"class_name": "Reference", "is_contained": False},
        "occurrencePeriod": {"class_name": "Period", "is_contained": False},
        "occurrenceTiming": {"class_name": "Timing", "is_contained": False},
        "performer": {"class_name": "Performer", "is_contained": True},
        "performingOrganization": {"class_name": "Reference", "is_contained": False},
        "requestingOrganization": {"class_name": "Reference", "is_contained": False},
        "costCenter": {"class_name": "Reference", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
        "bodysite": {"class_name": "CodeableConcept", "is_contained": False},
        "priceOverride": {"class_name": "Money", "is_contained": False},
        "enterer": {"class_name": "Reference", "is_contained": False},
        "reason": {"class_name": "CodeableConcept", "is_contained": False},
        "service": {"class_name": "Reference", "is_contained": False},
        "productReference": {"class_name": "Reference", "is_contained": False},
        "productCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "account": {"class_name": "Reference", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "supportingInformation": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        definitionUri: list["str"] = None,
        definitionCanonical: list["str"] = None,
        status: "str" = None,
        partOf: list["Reference"] = None,
        code: "CodeableConcept" = None,
        subject: "Reference" = None,
        context: "Reference" = None,
        occurrenceDateTime: "str" = None,
        occurrencePeriod: "Period" = None,
        occurrenceTiming: "Timing" = None,
        performer: list["Performer"] = None,
        performingOrganization: "Reference" = None,
        requestingOrganization: "Reference" = None,
        costCenter: "Reference" = None,
        quantity: "Quantity" = None,
        bodysite: list["CodeableConcept"] = None,
        factorOverride: "float" = None,
        priceOverride: "Money" = None,
        overrideReason: "str" = None,
        enterer: "Reference" = None,
        enteredDate: "str" = None,
        reason: list["CodeableConcept"] = None,
        service: list["Reference"] = None,
        productReference: "Reference" = None,
        productCodeableConcept: "CodeableConcept" = None,
        account: list["Reference"] = None,
        note: list["Annotation"] = None,
        supportingInformation: list["Reference"] = None,
    ):

        self.resourceType = "ChargeItem"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.definitionUri = definitionUri or []
        self.definitionCanonical = definitionCanonical or []
        self.status = status
        self.partOf = partOf or []
        self.code = code
        self.subject = subject
        self.context = context
        self.occurrenceDateTime = occurrenceDateTime
        self.occurrencePeriod = occurrencePeriod
        self.occurrenceTiming = occurrenceTiming
        self.performer = performer or []
        self.performingOrganization = performingOrganization
        self.requestingOrganization = requestingOrganization
        self.costCenter = costCenter
        self.quantity = quantity
        self.bodysite = bodysite or []
        self.factorOverride = factorOverride
        self.priceOverride = priceOverride
        self.overrideReason = overrideReason
        self.enterer = enterer
        self.enteredDate = enteredDate
        self.reason = reason or []
        self.service = service or []
        self.productReference = productReference
        self.productCodeableConcept = productCodeableConcept
        self.account = account or []
        self.note = note or []
        self.supportingInformation = supportingInformation or []

    @classmethod
    def from_dict(cls, data: dict) -> "ChargeItem":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ChargeItem":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Organization. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.Address import *
from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.ContactPoint import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.HumanName import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Resource import *


class Contact(FhirBaseModel):
    """Contact for the organization for a certain purpose.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept purpose: The type of contact
    :param HumanName name: A name associated with the contact
    :param ContactPoint telecom: Contact details (telephone, email, etc.)  for a contact
    :param Address address: Visiting or postal addresses for the contact
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "purpose": {"class_name": "CodeableConcept", "is_contained": False},
        "name": {"class_name": "HumanName", "is_contained": False},
        "telecom": {"class_name": "ContactPoint", "is_contained": False},
        "address": {"class_name": "Address", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        purpose: "CodeableConcept" = None,
        name: "HumanName" = None,
        telecom: list["ContactPoint"] = None,
        address: "Address" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.purpose = purpose
        self.name = name
        self.telecom = telecom or []
        self.address = address

    @classmethod
    def from_dict(cls, data: dict) -> "Organization":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Organization":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Organization(DomainResource):
    """A formally or informally recognized grouping of people or organizations formed for the purpose of achieving some form of collective action.  Includes companies, institutions, corporations, departments, community groups, healthcare practice groups, payer/insurer, etc.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Identifies this organization  across multiple systems
    :param bool active: Whether the organization's record is still in active use
    :param CodeableConcept type: Kind of organization
    :param str name: Name used for the organization
    :param str alias: A list of alternate names that the organization is known as, or was known as in the past
    :param ContactPoint telecom: A contact detail for the organization
    :param Address address: An address for the organization
    :param Reference partOf: The organization of which this organization forms a part
    :param Contact contact: Contact for the organization for a certain purpose
    :param Reference endpoint: Technical endpoints providing access to services operated for the organization
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "telecom": {"class_name": "ContactPoint", "is_contained": False},
        "address": {"class_name": "Address", "is_contained": False},
        "partOf": {"class_name": "Reference", "is_contained": False},
        "contact": {"class_name": "Contact", "is_contained": True},
        "endpoint": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        active: "bool" = None,
        type: list["CodeableConcept"] = None,
        name: "str" = None,
        alias: list["str"] = None,
        telecom: list["ContactPoint"] = None,
        address: list["Address"] = None,
        partOf: "Reference" = None,
        contact: list["Contact"] = None,
        endpoint: list["Reference"] = None,
    ):

        self.resourceType = "Organization"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.active = active
        self.type = type or []
        self.name = name
        self.alias = alias or []
        self.telecom = telecom or []
        self.address = address or []
        self.partOf = partOf
        self.contact = contact or []
        self.endpoint = endpoint or []

    @classmethod
    def from_dict(cls, data: dict) -> "Organization":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Organization":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Condition. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Age import *
from fhirmodels.R5.Annotation import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.CodeableReference import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Range import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *


class Participant(FhirBaseModel):
    """Indicates who or what participated in the activities related to the condition and how they were involved.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept function: Type of involvement
    :param Reference actor: Who or what participated in the activities related to the condition
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "function": {"class_name": "CodeableConcept", "is_contained": False},
        "actor": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        function: "CodeableConcept" = None,
        actor: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.function = function
        self.actor = actor

    @classmethod
    def from_dict(cls, data: dict) -> "Condition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Condition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Stage(FhirBaseModel):
    """A simple summary of the stage such as "Stage 3" or "Early Onset". The determination of the stage is disease-specific, such as cancer, retinopathy of prematurity, kidney diseases, Alzheimer's, or Parkinson disease.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept summary: Simple summary (disease specific)
    :param Reference assessment: Formal record of assessment
    :param CodeableConcept type: Kind of staging
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "summary": {"class_name": "CodeableConcept", "is_contained": False},
        "assessment": {"class_name": "Reference", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        summary: "CodeableConcept" = None,
        assessment: list["Reference"] = None,
        type: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.summary = summary
        self.assessment = assessment or []
        self.type = type

    @classmethod
    def from_dict(cls, data: dict) -> "Condition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Condition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Condition(DomainResource):
    """A clinical condition, problem, diagnosis, or other event, situation, issue, or clinical concept that has risen to a level of concern.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: External Ids for this condition
    :param CodeableConcept clinicalStatus: active | recurrence | relapse | inactive | remission | resolved | unknown
    :param CodeableConcept verificationStatus: unconfirmed | provisional | differential | confirmed | refuted | entered-in-error
    :param CodeableConcept category: problem-list-item | encounter-diagnosis
    :param CodeableConcept severity: Subjective severity of condition
    :param CodeableConcept code: Identification of the condition, problem or diagnosis
    :param CodeableConcept bodySite: Anatomical location, if relevant
    :param Reference subject: Who has the condition?
    :param Reference encounter: The Encounter during which this Condition was created
    :param str onsetDateTime: Estimated or actual date,  date-time, or age
    :param Age onsetAge: Estimated or actual date,  date-time, or age
    :param Period onsetPeriod: Estimated or actual date,  date-time, or age
    :param Range onsetRange: Estimated or actual date,  date-time, or age
    :param str onsetString: Estimated or actual date,  date-time, or age
    :param str abatementDateTime: When in resolution/remission
    :param Age abatementAge: When in resolution/remission
    :param Period abatementPeriod: When in resolution/remission
    :param Range abatementRange: When in resolution/remission
    :param str abatementString: When in resolution/remission
    :param str recordedDate: Date condition was first recorded
    :param Participant participant: Who or what participated in the activities related to the condition and how they were involved
    :param Stage stage: Stage/grade, usually assessed formally
    :param CodeableReference evidence: Supporting evidence for the verification status
    :param Annotation note: Additional information about the Condition
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "clinicalStatus": {"class_name": "CodeableConcept", "is_contained": False},
        "verificationStatus": {"class_name": "CodeableConcept", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "severity": {"class_name": "CodeableConcept", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "bodySite": {"class_name": "CodeableConcept", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "encounter": {"class_name": "Reference", "is_contained": False},
        "onsetAge": {"class_name": "Age", "is_contained": False},
        "onsetPeriod": {"class_name": "Period", "is_contained": False},
        "onsetRange": {"class_name": "Range", "is_contained": False},
        "abatementAge": {"class_name": "Age", "is_contained": False},
        "abatementPeriod": {"class_name": "Period", "is_contained": False},
        "abatementRange": {"class_name": "Range", "is_contained": False},
        "participant": {"class_name": "Participant", "is_contained": True},
        "stage": {"class_name": "Stage", "is_contained": True},
        "evidence": {"class_name": "CodeableReference", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        clinicalStatus: "CodeableConcept" = None,
        verificationStatus: "CodeableConcept" = None,
        category: list["CodeableConcept"] = None,
        severity: "CodeableConcept" = None,
        code: "CodeableConcept" = None,
        bodySite: list["CodeableConcept"] = None,
        subject: "Reference" = None,
        encounter: "Reference" = None,
        onsetDateTime: "str" = None,
        onsetAge: "Age" = None,
        onsetPeriod: "Period" = None,
        onsetRange: "Range" = None,
        onsetString: "str" = None,
        abatementDateTime: "str" = None,
        abatementAge: "Age" = None,
        abatementPeriod: "Period" = None,
        abatementRange: "Range" = None,
        abatementString: "str" = None,
        recordedDate: "str" = None,
        participant: list["Participant"] = None,
        stage: list["Stage"] = None,
        evidence: list["CodeableReference"] = None,
        note: list["Annotation"] = None,
    ):

        self.resourceType = "Condition"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.clinicalStatus = clinicalStatus
        self.verificationStatus = verificationStatus
        self.category = category or []
        self.severity = severity
        self.code = code
        self.bodySite = bodySite or []
        self.subject = subject
        self.encounter = encounter
        self.onsetDateTime = onsetDateTime
        self.onsetAge = onsetAge
        self.onsetPeriod = onsetPeriod
        self.onsetRange = onsetRange
        self.onsetString = onsetString
        self.abatementDateTime = abatementDateTime
        self.abatementAge = abatementAge
        self.abatementPeriod = abatementPeriod
        self.abatementRange = abatementRange
        self.abatementString = abatementString
        self.recordedDate = recordedDate
        self.participant = participant or []
        self.stage = stage or []
        self.evidence = evidence or []
        self.note = note or []

    @classmethod
    def from_dict(cls, data: dict) -> "Condition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Condition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for CarePlan. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Annotation import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.CodeableReference import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *


class Activity(FhirBaseModel):
    """Identifies an action that has occurred or is a planned action to occur as part of the plan. For example, a medication to be used, lab tests to perform, self-monitoring that has occurred, education etc.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableReference performedActivity: Results of the activity (concept, or Appointment, Encounter, Procedure, etc.)
    :param Annotation progress: Comments about the activity status/progress
    :param Reference plannedActivityReference: Activity that is intended to be part of the care plan
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "performedActivity": {"class_name": "CodeableReference", "is_contained": False},
        "progress": {"class_name": "Annotation", "is_contained": False},
        "plannedActivityReference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        performedActivity: list["CodeableReference"] = None,
        progress: list["Annotation"] = None,
        plannedActivityReference: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.performedActivity = performedActivity or []
        self.progress = progress or []
        self.plannedActivityReference = plannedActivityReference

    @classmethod
    def from_dict(cls, data: dict) -> "CarePlan":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "CarePlan":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class CarePlan(DomainResource):
    """Describes the intention of how one or more practitioners intend to deliver care for a particular patient, group or community for a period of time, possibly limited to care for a specific condition or set of conditions.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: External Ids for this plan
    :param str instantiatesCanonical: Instantiates FHIR protocol or definition
    :param str instantiatesUri: Instantiates external protocol or definition
    :param Reference basedOn: Fulfills plan, proposal or order
    :param Reference replaces: CarePlan replaced by this CarePlan
    :param Reference partOf: Part of referenced CarePlan
    :param str status: draft | active | on-hold | revoked | completed | entered-in-error | unknown
    :param str intent: proposal | plan | order | option | directive
    :param CodeableConcept category: Type of plan
    :param str title: Human-friendly name for the care plan
    :param str description: Summary of nature of plan
    :param Reference subject: Who the care plan is for
    :param Reference encounter: The Encounter during which this CarePlan was created
    :param Period period: Time period plan covers
    :param str created: Date record was first recorded
    :param Reference custodian: Who is the designated responsible party
    :param Reference contributor: Who provided the content of the care plan
    :param Reference careTeam: Who's involved in plan?
    :param CodeableReference addresses: Health issues this plan addresses
    :param Reference supportingInfo: Information considered as part of plan
    :param Reference goal: Desired outcome of plan
    :param Activity activity: Action to occur or has occurred as part of plan
    :param Annotation note: Comments about the plan
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "basedOn": {"class_name": "Reference", "is_contained": False},
        "replaces": {"class_name": "Reference", "is_contained": False},
        "partOf": {"class_name": "Reference", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "encounter": {"class_name": "Reference", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
        "custodian": {"class_name": "Reference", "is_contained": False},
        "contributor": {"class_name": "Reference", "is_contained": False},
        "careTeam": {"class_name": "Reference", "is_contained": False},
        "addresses": {"class_name": "CodeableReference", "is_contained": False},
        "supportingInfo": {"class_name": "Reference", "is_contained": False},
        "goal": {"class_name": "Reference", "is_contained": False},
        "activity": {"class_name": "Activity", "is_contained": True},
        "note": {"class_name": "Annotation", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        instantiatesCanonical: list["str"] = None,
        instantiatesUri: list["str"] = None,
        basedOn: list["Reference"] = None,
        replaces: list["Reference"] = None,
        partOf: list["Reference"] = None,
        status: "str" = None,
        intent: "str" = None,
        category: list["CodeableConcept"] = None,
        title: "str" = None,
        description: "str" = None,
        subject: "Reference" = None,
        encounter: "Reference" = None,
        period: "Period" = None,
        created: "str" = None,
        custodian: "Reference" = None,
        contributor: list["Reference"] = None,
        careTeam: list["Reference"] = None,
        addresses: list["CodeableReference"] = None,
        supportingInfo: list["Reference"] = None,
        goal: list["Reference"] = None,
        activity: list["Activity"] = None,
        note: list["Annotation"] = None,
    ):

        self.resourceType = "CarePlan"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.instantiatesCanonical = instantiatesCanonical or []
        self.instantiatesUri = instantiatesUri or []
        self.basedOn = basedOn or []
        self.replaces = replaces or []
        self.partOf = partOf or []
        self.status = status
        self.intent = intent
        self.category = category or []
        self.title = title
        self.description = description
        self.subject = subject
        self.encounter = encounter
        self.period = period
        self.created = created
        self.custodian = custodian
        self.contributor = contributor or []
        self.careTeam = careTeam or []
        self.addresses = addresses or []
        self.supportingInfo = supportingInfo or []
        self.goal = goal or []
        self.activity = activity or []
        self.note = note or []

    @classmethod
    def from_dict(cls, data: dict) -> "CarePlan":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "CarePlan":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Contract. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.Annotation import *
from fhirmodels.R4.Attachment import *
from fhirmodels.R4.BackboneElement import *
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.Coding import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Identifier import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Money import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.Period import *
from fhirmodels.R4.Quantity import *
from fhirmodels.R4.Reference import *
from fhirmodels.R4.Resource import *
from fhirmodels.R4.Signature import *
from fhirmodels.R4.Timing import *


class ContentDefinition(FhirBaseModel):
    """Precusory content developed with a focus and intent of supporting the formation a Contract instance, which may be associated with and transformable into a Contract.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Content structure and use
    :param CodeableConcept subType: Detailed Content Type Definition
    :param Reference publisher: Publisher Entity
    :param str publicationDate: When published
    :param str publicationStatus: amended | appended | cancelled | disputed | entered-in-error | executable | executed | negotiable | offered | policy | rejected | renewed | revoked | resolved | terminated
    :param str copyright: Publication Ownership
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "subType": {"class_name": "CodeableConcept", "is_contained": False},
        "publisher": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        subType: "CodeableConcept" = None,
        publisher: "Reference" = None,
        publicationDate: "str" = None,
        publicationStatus: "str" = None,
        copyright: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.subType = subType
        self.publisher = publisher
        self.publicationDate = publicationDate
        self.publicationStatus = publicationStatus
        self.copyright = copyright

    @classmethod
    def from_dict(cls, data: dict) -> "Contract":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Contract":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class SecurityLabel(FhirBaseModel):
    """Security labels that protect the handling of information about the term and its elements, which may be specifically identified..:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int number: Link to Security Labels
    :param Coding classification: Confidentiality Protection
    :param Coding category: Applicable Policy
    :param Coding control: Handling Instructions
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "classification": {"class_name": "Coding", "is_contained": False},
        "category": {"class_name": "Coding", "is_contained": False},
        "control": {"class_name": "Coding", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        number: list["int"] = None,
        classification: "Coding" = None,
        category: list["Coding"] = None,
        control: list["Coding"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.number = number or []
        self.classification = classification
        self.category = category or []
        self.control = control or []

    @classmethod
    def from_dict(cls, data: dict) -> "Contract":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Contract":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Party(FhirBaseModel):
    """Offer Recipient.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference reference: Referenced entity
    :param CodeableConcept role: Participant engagement type
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "reference": {"class_name": "Reference", "is_contained": False},
        "role": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        reference: list["Reference"] = None,
        role: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.reference = reference or []
        self.role = role

    @classmethod
    def from_dict(cls, data: dict) -> "Contract":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Contract":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Answer(FhirBaseModel):
    """Response to offer text.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param bool valueBoolean: The actual answer response
    :param float valueDecimal: The actual answer response
    :param int valueInteger: The actual answer response
    :param str valueDate: The actual answer response
    :param str valueDateTime: The actual answer response
    :param str valueTime: The actual answer response
    :param str valueString: The actual answer response
    :param str valueUri: The actual answer response
    :param Attachment valueAttachment: The actual answer response
    :param Coding valueCoding: The actual answer response
    :param Quantity valueQuantity: The actual answer response
    :param Reference valueReference: The actual answer response
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "valueAttachment": {"class_name": "Attachment", "is_contained": False},
        "valueCoding": {"class_name": "Coding", "is_contained": False},
        "valueQuantity": {"class_name": "Quantity", "is_contained": False},
        "valueReference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        valueBoolean: "bool" = None,
        valueDecimal: "float" = None,
        valueInteger: "int" = None,
        valueDate: "str" = None,
        valueDateTime: "str" = None,
        valueTime: "str" = None,
        valueString: "str" = None,
        valueUri: "str" = None,
        valueAttachment: "Attachment" = None,
        valueCoding: "Coding" = None,
        valueQuantity: "Quantity" = None,
        valueReference: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.valueBoolean = valueBoolean
        self.valueDecimal = valueDecimal
        self.valueInteger = valueInteger
        self.valueDate = valueDate
        self.valueDateTime = valueDateTime
        self.valueTime = valueTime
        self.valueString = valueString
        self.valueUri = valueUri
        self.valueAttachment = valueAttachment
        self.valueCoding = valueCoding
        self.valueQuantity = valueQuantity
        self.valueReference = valueReference

    @classmethod
    def from_dict(cls, data: dict) -> "Contract":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Contract":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Offer(FhirBaseModel):
    """The matter of concern in the context of this provision of the agrement.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Identifier identifier: Offer business ID
    :param Party party: Offer Recipient
    :param Reference topic: Negotiable offer asset
    :param CodeableConcept type: Contract Offer Type or Form
    :param CodeableConcept decision: Accepting party choice
    :param CodeableConcept decisionMode: How decision is conveyed
    :param Answer answer: Response to offer text
    :param str text: Human readable offer text
    :param str linkId: Pointer to text
    :param int securityLabelNumber: Offer restriction numbers
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "party": {"class_name": "Party", "is_contained": True},
        "topic": {"class_name": "Reference", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "decision": {"class_name": "CodeableConcept", "is_contained": False},
        "decisionMode": {"class_name": "CodeableConcept", "is_contained": False},
        "answer": {"class_name": "Answer", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        party: list["Party"] = None,
        topic: "Reference" = None,
        type: "CodeableConcept" = None,
        decision: "CodeableConcept" = None,
        decisionMode: list["CodeableConcept"] = None,
        answer: list["Answer"] = None,
        text: "str" = None,
        linkId: list["str"] = None,
        securityLabelNumber: list["int"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.party = party or []
        self.topic = topic
        self.type = type
        self.decision = decision
        self.decisionMode = decisionMode or []
        self.answer = answer or []
        self.text = text
        self.linkId = linkId or []
        self.securityLabelNumber = securityLabelNumber or []

    @classmethod
    def from_dict(cls, data: dict) -> "Contract":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Contract":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Context(FhirBaseModel):
    """Circumstance of the asset.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference reference: Creator,custodian or owner
    :param CodeableConcept code: Codeable asset context
    :param str text: Context description
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "reference": {"class_name": "Reference", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        reference: "Reference" = None,
        code: list["CodeableConcept"] = None,
        text: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.reference = reference
        self.code = code or []
        self.text = text

    @classmethod
    def from_dict(cls, data: dict) -> "Contract":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Contract":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ValuedItem(FhirBaseModel):
    """Contract Valued Item List.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept entityCodeableConcept: Contract Valued Item Type
    :param Reference entityReference: Contract Valued Item Type
    :param Identifier identifier: Contract Valued Item Number
    :param str effectiveTime: Contract Valued Item Effective Tiem
    :param Quantity quantity: Count of Contract Valued Items
    :param Money unitPrice: Contract Valued Item fee, charge, or cost
    :param float factor: Contract Valued Item Price Scaling Factor
    :param float points: Contract Valued Item Difficulty Scaling Factor
    :param Money net: Total Contract Valued Item Value
    :param str payment: Terms of valuation
    :param str paymentDate: When payment is due
    :param Reference responsible: Who will make payment
    :param Reference recipient: Who will receive payment
    :param str linkId: Pointer to specific item
    :param int securityLabelNumber: Security Labels that define affected terms
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "entityCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "entityReference": {"class_name": "Reference", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
        "unitPrice": {"class_name": "Money", "is_contained": False},
        "net": {"class_name": "Money", "is_contained": False},
        "responsible": {"class_name": "Reference", "is_contained": False},
        "recipient": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        entityCodeableConcept: "CodeableConcept" = None,
        entityReference: "Reference" = None,
        identifier: "Identifier" = None,
        effectiveTime: "str" = None,
        quantity: "Quantity" = None,
        unitPrice: "Money" = None,
        factor: "float" = None,
        points: "float" = None,
        net: "Money" = None,
        payment: "str" = None,
        paymentDate: "str" = None,
        responsible: "Reference" = None,
        recipient: "Reference" = None,
        linkId: list["str"] = None,
        securityLabelNumber: list["int"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.entityCodeableConcept = entityCodeableConcept
        self.entityReference = entityReference
        self.identifier = identifier
        self.effectiveTime = effectiveTime
        self.quantity = quantity
        self.unitPrice = unitPrice
        self.factor = factor
        self.points = points
        self.net = net
        self.payment = payment
        self.paymentDate = paymentDate
        self.responsible = responsible
        self.recipient = recipient
        self.linkId = linkId or []
        self.securityLabelNumber = securityLabelNumber or []

    @classmethod
    def from_dict(cls, data: dict) -> "Contract":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Contract":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Asset(FhirBaseModel):
    """Contract Term Asset List.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept scope: Range of asset
    :param CodeableConcept type: Asset category
    :param Reference typeReference: Associated entities
    :param CodeableConcept subtype: Asset sub-category
    :param Coding relationship: Kinship of the asset
    :param Context context: Circumstance of the asset
    :param str condition: Quality desctiption of asset
    :param CodeableConcept periodType: Asset availability types
    :param Period period: Time period of the asset
    :param Period usePeriod: Time period
    :param str text: Asset clause or question text
    :param str linkId: Pointer to asset text
    :param Answer answer: Response to assets
    :param int securityLabelNumber: Asset restriction numbers
    :param ValuedItem valuedItem: Contract Valued Item List
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "scope": {"class_name": "CodeableConcept", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "typeReference": {"class_name": "Reference", "is_contained": False},
        "subtype": {"class_name": "CodeableConcept", "is_contained": False},
        "relationship": {"class_name": "Coding", "is_contained": False},
        "context": {"class_name": "Context", "is_contained": True},
        "periodType": {"class_name": "CodeableConcept", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
        "usePeriod": {"class_name": "Period", "is_contained": False},
        "answer": {"class_name": "Answer", "is_contained": True},
        "valuedItem": {"class_name": "ValuedItem", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        scope: "CodeableConcept" = None,
        type: list["CodeableConcept"] = None,
        typeReference: list["Reference"] = None,
        subtype: list["CodeableConcept"] = None,
        relationship: "Coding" = None,
        context: list["Context"] = None,
        condition: "str" = None,
        periodType: list["CodeableConcept"] = None,
        period: list["Period"] = None,
        usePeriod: list["Period"] = None,
        text: "str" = None,
        linkId: list["str"] = None,
        answer: list["Answer"] = None,
        securityLabelNumber: list["int"] = None,
        valuedItem: list["ValuedItem"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.scope = scope
        self.type = type or []
        self.typeReference = typeReference or []
        self.subtype = subtype or []
        self.relationship = relationship
        self.context = context or []
        self.condition = condition
        self.periodType = periodType or []
        self.period = period or []
        self.usePeriod = usePeriod or []
        self.text = text
        self.linkId = linkId or []
        self.answer = answer or []
        self.securityLabelNumber = securityLabelNumber or []
        self.valuedItem = valuedItem or []

    @classmethod
    def from_dict(cls, data: dict) -> "Contract":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Contract":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Subject(FhirBaseModel):
    """Entity of the action.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference reference: Entity of the action
    :param CodeableConcept role: Role type of the agent
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "reference": {"class_name": "Reference", "is_contained": False},
        "role": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        reference: list["Reference"] = None,
        role: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.reference = reference or []
        self.role = role

    @classmethod
    def from_dict(cls, data: dict) -> "Contract":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Contract":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Action(FhirBaseModel):
    """An actor taking a role in an activity for which it can be assigned some degree of responsibility for the activity taking place.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param bool doNotPerform: True if the term prohibits the  action
    :param CodeableConcept type: Type or form of the action
    :param Subject subject: Entity of the action
    :param CodeableConcept intent: Purpose for the Contract Term Action
    :param str linkId: Pointer to specific item
    :param CodeableConcept status: State of the action
    :param Reference context: Episode associated with action
    :param str contextLinkId: Pointer to specific item
    :param str occurrenceDateTime: When action happens
    :param Period occurrencePeriod: When action happens
    :param Timing occurrenceTiming: When action happens
    :param Reference requester: Who asked for action
    :param str requesterLinkId: Pointer to specific item
    :param CodeableConcept performerType: Kind of service performer
    :param CodeableConcept performerRole: Competency of the performer
    :param Reference performer: Actor that wil execute (or not) the action
    :param str performerLinkId: Pointer to specific item
    :param CodeableConcept reasonCode: Why is action (not) needed?
    :param Reference reasonReference: Why is action (not) needed?
    :param str reason: Why action is to be performed
    :param str reasonLinkId: Pointer to specific item
    :param Annotation note: Comments about the action
    :param int securityLabelNumber: Action restriction numbers
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "subject": {"class_name": "Subject", "is_contained": True},
        "intent": {"class_name": "CodeableConcept", "is_contained": False},
        "status": {"class_name": "CodeableConcept", "is_contained": False},
        "context": {"class_name": "Reference", "is_contained": False},
        "occurrencePeriod": {"class_name": "Period", "is_contained": False},
        "occurrenceTiming": {"class_name": "Timing", "is_contained": False},
        "requester": {"class_name": "Reference", "is_contained": False},
        "performerType": {"class_name": "CodeableConcept", "is_contained": False},
        "performerRole": {"class_name": "CodeableConcept", "is_contained": False},
        "performer": {"class_name": "Reference", "is_contained": False},
        "reasonCode": {"class_name": "CodeableConcept", "is_contained": False},
        "reasonReference": {"class_name": "Reference", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        doNotPerform: "bool" = None,
        type: "CodeableConcept" = None,
        subject: list["Subject"] = None,
        intent: "CodeableConcept" = None,
        linkId: list["str"] = None,
        status: "CodeableConcept" = None,
        context: "Reference" = None,
        contextLinkId: list["str"] = None,
        occurrenceDateTime: "str" = None,
        occurrencePeriod: "Period" = None,
        occurrenceTiming: "Timing" = None,
        requester: list["Reference"] = None,
        requesterLinkId: list["str"] = None,
        performerType: list["CodeableConcept"] = None,
        performerRole: "CodeableConcept" = None,
        performer: "Reference" = None,
        performerLinkId: list["str"] = None,
        reasonCode: list["CodeableConcept"] = None,
        reasonReference: list["Reference"] = None,
        reason: list["str"] = None,
        reasonLinkId: list["str"] = None,
        note: list["Annotation"] = None,
        securityLabelNumber: list["int"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.doNotPerform = doNotPerform
        self.type = type
        self.subject = subject or []
        self.intent = intent
        self.linkId = linkId or []
        self.status = status
        self.context = context
        self.contextLinkId = contextLinkId or []
        self.occurrenceDateTime = occurrenceDateTime
        self.occurrencePeriod = occurrencePeriod
        self.occurrenceTiming = occurrenceTiming
        self.requester = requester or []
        self.requesterLinkId = requesterLinkId or []
        self.performerType = performerType or []
        self.performerRole = performerRole
        self.performer = performer
        self.performerLinkId = performerLinkId or []
        self.reasonCode = reasonCode or []
        self.reasonReference = reasonReference or []
        self.reason = reason or []
        self.reasonLinkId = reasonLinkId or []
        self.note = note or []
        self.securityLabelNumber = securityLabelNumber or []

    @classmethod
    def from_dict(cls, data: dict) -> "Contract":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Contract":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Term(FhirBaseModel):
    """One or more Contract Provisions, which may be related and conveyed as a group, and may contain nested groups.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Identifier identifier: Contract Term Number
    :param str issued: Contract Term Issue Date Time
    :param Period applies: Contract Term Effective Time
    :param CodeableConcept topicCodeableConcept: Term Concern
    :param Reference topicReference: Term Concern
    :param CodeableConcept type: Contract Term Type or Form
    :param CodeableConcept subType: Contract Term Type specific classification
    :param str text: Term Statement
    :param SecurityLabel securityLabel: Protection for the Term
    :param Offer offer: Context of the Contract term
    :param Asset asset: Contract Term Asset List
    :param Action action: Entity being ascribed responsibility
    :param Group group: Nested Contract Term Group
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "applies": {"class_name": "Period", "is_contained": False},
        "topicCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "topicReference": {"class_name": "Reference", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "subType": {"class_name": "CodeableConcept", "is_contained": False},
        "securityLabel": {"class_name": "SecurityLabel", "is_contained": True},
        "offer": {"class_name": "Offer", "is_contained": True},
        "asset": {"class_name": "Asset", "is_contained": True},
        "action": {"class_name": "Action", "is_contained": True},
        "group": {"class_name": "Group", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: "Identifier" = None,
        issued: "str" = None,
        applies: "Period" = None,
        topicCodeableConcept: "CodeableConcept" = None,
        topicReference: "Reference" = None,
        type: "CodeableConcept" = None,
        subType: "CodeableConcept" = None,
        text: "str" = None,
        securityLabel: list["SecurityLabel"] = None,
        offer: "Offer" = None,
        asset: list["Asset"] = None,
        action: list["Action"] = None,
        group: list["Group"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier
        self.issued = issued
        self.applies = applies
        self.topicCodeableConcept = topicCodeableConcept
        self.topicReference = topicReference
        self.type = type
        self.subType = subType
        self.text = text
        self.securityLabel = securityLabel or []
        self.offer = offer
        self.asset = asset or []
        self.action = action or []
        self.group = group or []

    @classmethod
    def from_dict(cls, data: dict) -> "Contract":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Contract":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Signer(FhirBaseModel):
    """Parties with legal standing in the Contract, including the principal parties, the grantor(s) and grantee(s), which are any person or organization bound by the contract, and any ancillary parties, which facilitate the execution of the contract such as a notary or witness.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Coding type: Contract Signatory Role
    :param Reference party: Contract Signatory Party
    :param Signature signature: Contract Documentation Signature
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "Coding", "is_contained": False},
        "party": {"class_name": "Reference", "is_contained": False},
        "signature": {"class_name": "Signature", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "Coding" = None,
        party: "Reference" = None,
        signature: list["Signature"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.party = party
        self.signature = signature or []

    @classmethod
    def from_dict(cls, data: dict) -> "Contract":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Contract":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Friendly(FhirBaseModel):
    """The "patient friendly language" versionof the Contract in whole or in parts. "Patient friendly language" means the representation of the Contract and Contract Provisions in a manner that is readily accessible and understandable by a layperson in accordance with best practices for communication styles that ensure that those agreeing to or signing the Contract understand the roles, actions, obligations, responsibilities, and implication of the agreement.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Attachment contentAttachment: Easily comprehended representation of this Contract
    :param Reference contentReference: Easily comprehended representation of this Contract
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "contentAttachment": {"class_name": "Attachment", "is_contained": False},
        "contentReference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        contentAttachment: "Attachment" = None,
        contentReference: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.contentAttachment = contentAttachment
        self.contentReference = contentReference

    @classmethod
    def from_dict(cls, data: dict) -> "Contract":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Contract":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Legal(FhirBaseModel):
    """List of Legal expressions or representations of this Contract.:param CodeableConcept legalState: Negotiation status
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Attachment contentAttachment: Contract Legal Text
    :param Reference contentReference: Contract Legal Text
    :param Attachment legallyBindingAttachment: Binding Contract
    :param Reference legallyBindingReference: Binding Contract
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "legalState": {"class_name": "CodeableConcept", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "contentAttachment": {"class_name": "Attachment", "is_contained": False},
        "contentReference": {"class_name": "Reference", "is_contained": False},
        "legallyBindingAttachment": {"class_name": "Attachment", "is_contained": False},
        "legallyBindingReference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        legalState: "CodeableConcept" = None,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        contentAttachment: "Attachment" = None,
        contentReference: "Reference" = None,
        legallyBindingAttachment: "Attachment" = None,
        legallyBindingReference: "Reference" = None,
    ):
        self.legalState = legalState
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.contentAttachment = contentAttachment
        self.contentReference = contentReference
        self.legallyBindingAttachment = legallyBindingAttachment
        self.legallyBindingReference = legallyBindingReference

    @classmethod
    def from_dict(cls, data: dict) -> "Contract":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Contract":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Rule(FhirBaseModel):
    """List of Computable Policy Rule Language Representations of this Contract.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Attachment contentAttachment: Computable Contract Rules
    :param Reference contentReference: Computable Contract Rules
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "contentAttachment": {"class_name": "Attachment", "is_contained": False},
        "contentReference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        contentAttachment: "Attachment" = None,
        contentReference: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.contentAttachment = contentAttachment
        self.contentReference = contentReference

    @classmethod
    def from_dict(cls, data: dict) -> "Contract":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Contract":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Contract(DomainResource):
    """Legally enforceable, formally recorded unilateral or bilateral directive i.e., a policy or agreement.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Contract number
    :param str url: Basal definition
    :param str version: Business edition
    :param str status: amended | appended | cancelled | disputed | entered-in-error | executable | executed | negotiable | offered | policy | rejected | renewed | revoked | resolved | terminated
    :param CodeableConcept legalState: Negotiation status
    :param Reference instantiatesCanonical: Source Contract Definition
    :param str instantiatesUri: External Contract Definition
    :param CodeableConcept contentDerivative: Content derived from the basal information
    :param str issued: When this Contract was issued
    :param Period applies: Effective time
    :param CodeableConcept expirationType: Contract cessation cause
    :param Reference subject: Contract Target Entity
    :param Reference authority: Authority under which this Contract has standing
    :param Reference domain: A sphere of control governed by an authoritative jurisdiction, organization, or person
    :param Reference site: Specific Location
    :param str name: Computer friendly designation
    :param str title: Human Friendly name
    :param str subtitle: Subordinate Friendly name
    :param str alias: Acronym or short name
    :param Reference author: Source of Contract
    :param CodeableConcept scope: Range of Legal Concerns
    :param CodeableConcept topicCodeableConcept: Focus of contract interest
    :param Reference topicReference: Focus of contract interest
    :param CodeableConcept type: Legal instrument category
    :param CodeableConcept subType: Subtype within the context of type
    :param ContentDefinition contentDefinition: Contract precursor content
    :param Term term: Contract Term List
    :param Reference supportingInfo: Extra Information
    :param Reference relevantHistory: Key event in Contract History
    :param Signer signer: Contract Signatory
    :param Friendly friendly: Contract Friendly Language
    :param Legal legal: Contract Legal Language
    :param Rule rule: Computable Contract Language
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "legalState": {"class_name": "CodeableConcept", "is_contained": False},
        "instantiatesCanonical": {"class_name": "Reference", "is_contained": False},
        "contentDerivative": {"class_name": "CodeableConcept", "is_contained": False},
        "applies": {"class_name": "Period", "is_contained": False},
        "expirationType": {"class_name": "CodeableConcept", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "authority": {"class_name": "Reference", "is_contained": False},
        "domain": {"class_name": "Reference", "is_contained": False},
        "site": {"class_name": "Reference", "is_contained": False},
        "author": {"class_name": "Reference", "is_contained": False},
        "scope": {"class_name": "CodeableConcept", "is_contained": False},
        "topicCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "topicReference": {"class_name": "Reference", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "subType": {"class_name": "CodeableConcept", "is_contained": False},
        "contentDefinition": {"class_name": "ContentDefinition", "is_contained": True},
        "term": {"class_name": "Term", "is_contained": True},
        "supportingInfo": {"class_name": "Reference", "is_contained": False},
        "relevantHistory": {"class_name": "Reference", "is_contained": False},
        "signer": {"class_name": "Signer", "is_contained": True},
        "friendly": {"class_name": "Friendly", "is_contained": True},
        "legal": {"class_name": "Legal", "is_contained": True},
        "rule": {"class_name": "Rule", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        url: "str" = None,
        version: "str" = None,
        status: "str" = None,
        legalState: "CodeableConcept" = None,
        instantiatesCanonical: "Reference" = None,
        instantiatesUri: "str" = None,
        contentDerivative: "CodeableConcept" = None,
        issued: "str" = None,
        applies: "Period" = None,
        expirationType: "CodeableConcept" = None,
        subject: list["Reference"] = None,
        authority: list["Reference"] = None,
        domain: list["Reference"] = None,
        site: list["Reference"] = None,
        name: "str" = None,
        title: "str" = None,
        subtitle: "str" = None,
        alias: list["str"] = None,
        author: "Reference" = None,
        scope: "CodeableConcept" = None,
        topicCodeableConcept: "CodeableConcept" = None,
        topicReference: "Reference" = None,
        type: "CodeableConcept" = None,
        subType: list["CodeableConcept"] = None,
        contentDefinition: "ContentDefinition" = None,
        term: list["Term"] = None,
        supportingInfo: list["Reference"] = None,
        relevantHistory: list["Reference"] = None,
        signer: list["Signer"] = None,
        friendly: list["Friendly"] = None,
        legal: list["Legal"] = None,
        rule: list["Rule"] = None,
    ):

        self.resourceType = "Contract"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.url = url
        self.version = version
        self.status = status
        self.legalState = legalState
        self.instantiatesCanonical = instantiatesCanonical
        self.instantiatesUri = instantiatesUri
        self.contentDerivative = contentDerivative
        self.issued = issued
        self.applies = applies
        self.expirationType = expirationType
        self.subject = subject or []
        self.authority = authority or []
        self.domain = domain or []
        self.site = site or []
        self.name = name
        self.title = title
        self.subtitle = subtitle
        self.alias = alias or []
        self.author = author
        self.scope = scope
        self.topicCodeableConcept = topicCodeableConcept
        self.topicReference = topicReference
        self.type = type
        self.subType = subType or []
        self.contentDefinition = contentDefinition
        self.term = term or []
        self.supportingInfo = supportingInfo or []
        self.relevantHistory = relevantHistory or []
        self.signer = signer or []
        self.friendly = friendly or []
        self.legal = legal or []
        self.rule = rule or []

    @classmethod
    def from_dict(cls, data: dict) -> "Contract":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Contract":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Dosage. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.Element import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Quantity import *
from fhirmodels.R5.Range import *
from fhirmodels.R5.Ratio import *
from fhirmodels.R5.Timing import *


class DoseAndRate(FhirBaseModel):
    """Depending on the resource,this is the amount of medication administered, to  be administered or typical amount to be administered.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param CodeableConcept type: The kind of dose or rate specified
    :param Range doseRange: Amount of medication per dose
    :param Quantity doseQuantity: Amount of medication per dose
    :param Ratio rateRatio: Amount of medication per unit of time
    :param Range rateRange: Amount of medication per unit of time
    :param Quantity rateQuantity: Amount of medication per unit of time
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "doseRange": {"class_name": "Range", "is_contained": False},
        "doseQuantity": {"class_name": "Quantity", "is_contained": False},
        "rateRatio": {"class_name": "Ratio", "is_contained": False},
        "rateRange": {"class_name": "Range", "is_contained": False},
        "rateQuantity": {"class_name": "Quantity", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        doseRange: "Range" = None,
        doseQuantity: "Quantity" = None,
        rateRatio: "Ratio" = None,
        rateRange: "Range" = None,
        rateQuantity: "Quantity" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.type = type
        self.doseRange = doseRange
        self.doseQuantity = doseQuantity
        self.rateRatio = rateRatio
        self.rateRange = rateRange
        self.rateQuantity = rateQuantity

    @classmethod
    def from_dict(cls, data: dict) -> "Dosage":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Dosage":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Dosage(FhirBaseModel):
    """Dosage Type: Indicates how the medication is/was taken or should be taken by the patient.
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int sequence: The order of the dosage instructions
    :param str text: Free text dosage instructions e.g. SIG
    :param CodeableConcept additionalInstruction: Supplemental instruction or warnings to the patient - e.g. "with meals", "may cause drowsiness"
    :param str patientInstruction: Patient or consumer oriented instructions
    :param Timing timing: When medication should be administered
    :param bool asNeeded: Take "as needed"
    :param CodeableConcept asNeededFor: Take "as needed" (for x)
    :param CodeableConcept site: Body site to administer to
    :param CodeableConcept route: How drug should enter body
    :param CodeableConcept method: Technique for administering medication
    :param DoseAndRate doseAndRate: Amount of medication administered, to be administered or typical amount to be administered
    :param Ratio maxDosePerPeriod: Upper limit on medication per unit of time
    :param Quantity maxDosePerAdministration: Upper limit on medication per administration
    :param Quantity maxDosePerLifetime: Upper limit on medication per lifetime of the patient
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "additionalInstruction": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "timing": {"class_name": "Timing", "is_contained": False},
        "asNeededFor": {"class_name": "CodeableConcept", "is_contained": False},
        "site": {"class_name": "CodeableConcept", "is_contained": False},
        "route": {"class_name": "CodeableConcept", "is_contained": False},
        "method": {"class_name": "CodeableConcept", "is_contained": False},
        "doseAndRate": {"class_name": "DoseAndRate", "is_contained": True},
        "maxDosePerPeriod": {"class_name": "Ratio", "is_contained": False},
        "maxDosePerAdministration": {"class_name": "Quantity", "is_contained": False},
        "maxDosePerLifetime": {"class_name": "Quantity", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        sequence: "int" = None,
        text: "str" = None,
        additionalInstruction: list["CodeableConcept"] = None,
        patientInstruction: "str" = None,
        timing: "Timing" = None,
        asNeeded: "bool" = None,
        asNeededFor: list["CodeableConcept"] = None,
        site: "CodeableConcept" = None,
        route: "CodeableConcept" = None,
        method: "CodeableConcept" = None,
        doseAndRate: list["DoseAndRate"] = None,
        maxDosePerPeriod: list["Ratio"] = None,
        maxDosePerAdministration: "Quantity" = None,
        maxDosePerLifetime: "Quantity" = None,
    ):

        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.sequence = sequence
        self.text = text
        self.additionalInstruction = additionalInstruction or []
        self.patientInstruction = patientInstruction
        self.timing = timing
        self.asNeeded = asNeeded
        self.asNeededFor = asNeededFor or []
        self.site = site
        self.route = route
        self.method = method
        self.doseAndRate = doseAndRate or []
        self.maxDosePerPeriod = maxDosePerPeriod or []
        self.maxDosePerAdministration = maxDosePerAdministration
        self.maxDosePerLifetime = maxDosePerLifetime

    @classmethod
    def from_dict(cls, data: dict) -> "Dosage":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Dosage":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for ExampleScenario. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.ContactDetail import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Resource import *
from fhirmodels.R4B.UsageContext import *


class Actor(FhirBaseModel):
    """Actor participating in the resource.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str actorId: ID or acronym of the actor
    :param str type: person | entity
    :param str name: The name of the actor as shown in the page
    :param str description: The description of the actor
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        actorId: "str" = None,
        type: "str" = None,
        name: "str" = None,
        description: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.actorId = actorId
        self.type = type
        self.name = name
        self.description = description

    @classmethod
    def from_dict(cls, data: dict) -> "ExampleScenario":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ExampleScenario":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Version(FhirBaseModel):
    """A specific version of the resource.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str versionId: The identifier of a specific version of a resource
    :param str description: The description of the resource version
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        versionId: "str" = None,
        description: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.versionId = versionId
        self.description = description

    @classmethod
    def from_dict(cls, data: dict) -> "ExampleScenario":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ExampleScenario":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ContainedInstance(FhirBaseModel):
    """Resources contained in the instance (e.g. the observations contained in a bundle).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str resourceId: Each resource contained in the instance
    :param str versionId: A specific version of a resource contained in the instance
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        resourceId: "str" = None,
        versionId: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.resourceId = resourceId
        self.versionId = versionId

    @classmethod
    def from_dict(cls, data: dict) -> "ExampleScenario":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ExampleScenario":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Instance(FhirBaseModel):
    """Each resource and each version that is present in the workflow.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str resourceId: The id of the resource for referencing
    :param str resourceType: The type of the resource
    :param str name: A short name for the resource instance
    :param str description: Human-friendly description of the resource instance
    :param Version version: A specific version of the resource
    :param ContainedInstance containedInstance: Resources contained in the instance
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "version": {"class_name": "Version", "is_contained": True},
        "containedInstance": {"class_name": "ContainedInstance", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        resourceId: "str" = None,
        resourceType: "str" = None,
        name: "str" = None,
        description: "str" = None,
        version: list["Version"] = None,
        containedInstance: list["ContainedInstance"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.resourceId = resourceId
        self.resourceType = resourceType
        self.name = name
        self.description = description
        self.version = version or []
        self.containedInstance = containedInstance or []

    @classmethod
    def from_dict(cls, data: dict) -> "ExampleScenario":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ExampleScenario":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Operation(FhirBaseModel):
    """Each interaction or action.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str number: The sequential number of the interaction
    :param str type: The type of operation - CRUD
    :param str name: The human-friendly name of the interaction
    :param str initiator: Who starts the transaction
    :param str receiver: Who receives the transaction
    :param str description: A comment to be inserted in the diagram
    :param bool initiatorActive: Whether the initiator is deactivated right after the transaction
    :param bool receiverActive: Whether the receiver is deactivated right after the transaction
    :param Request request: Each resource instance used by the initiator
    :param Response response: Each resource instance used by the responder
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "request": {"class_name": "Request", "is_contained": True},
        "response": {"class_name": "Response", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        number: "str" = None,
        type: "str" = None,
        name: "str" = None,
        initiator: "str" = None,
        receiver: "str" = None,
        description: "str" = None,
        initiatorActive: "bool" = None,
        receiverActive: "bool" = None,
        request: "Request" = None,
        response: "Response" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.number = number
        self.type = type
        self.name = name
        self.initiator = initiator
        self.receiver = receiver
        self.description = description
        self.initiatorActive = initiatorActive
        self.receiverActive = receiverActive
        self.request = request
        self.response = response

    @classmethod
    def from_dict(cls, data: dict) -> "ExampleScenario":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ExampleScenario":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Alternative(FhirBaseModel):
    """Indicates an alternative step that can be taken instead of the operations on the base step in exceptional/atypical circumstances.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str title: Label for alternative
    :param str description: A human-readable description of each option
    :param Step step: What happens in each alternative option
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "step": {"class_name": "Step", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        title: "str" = None,
        description: "str" = None,
        step: list["Step"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.title = title
        self.description = description
        self.step = step or []

    @classmethod
    def from_dict(cls, data: dict) -> "ExampleScenario":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ExampleScenario":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Step(FhirBaseModel):
    """Each step of the process.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Process process: Nested process
    :param bool pause: If there is a pause in the flow
    :param Operation operation: Each interaction or action
    :param Alternative alternative: Alternate non-typical step action
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "process": {"class_name": "Process", "is_contained": True},
        "operation": {"class_name": "Operation", "is_contained": True},
        "alternative": {"class_name": "Alternative", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        process: list["Process"] = None,
        pause: "bool" = None,
        operation: "Operation" = None,
        alternative: list["Alternative"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.process = process or []
        self.pause = pause
        self.operation = operation
        self.alternative = alternative or []

    @classmethod
    def from_dict(cls, data: dict) -> "ExampleScenario":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ExampleScenario":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Process(FhirBaseModel):
    """Each major process - a group of operations.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str title: The diagram title of the group of operations
    :param str description: A longer description of the group of operations
    :param str preConditions: Description of initial status before the process starts
    :param str postConditions: Description of final status after the process ends
    :param Step step: Each step of the process
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "step": {"class_name": "Step", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        title: "str" = None,
        description: "str" = None,
        preConditions: "str" = None,
        postConditions: "str" = None,
        step: list["Step"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.title = title
        self.description = description
        self.preConditions = preConditions
        self.postConditions = postConditions
        self.step = step or []

    @classmethod
    def from_dict(cls, data: dict) -> "ExampleScenario":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ExampleScenario":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ExampleScenario(DomainResource):
    """Example of workflow instance.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param str url: Canonical identifier for this example scenario, represented as a URI (globally unique)
    :param Identifier identifier: Additional identifier for the example scenario
    :param str version: Business version of the example scenario
    :param str name: Name for this example scenario (computer friendly)
    :param str status: draft | active | retired | unknown
    :param bool experimental: For testing purposes, not real usage
    :param str date: Date last changed
    :param str publisher: Name of the publisher (organization or individual)
    :param ContactDetail contact: Contact details for the publisher
    :param UsageContext useContext: The context that the content is intended to support
    :param CodeableConcept jurisdiction: Intended jurisdiction for example scenario (if applicable)
    :param str copyright: Use and/or publishing restrictions
    :param str purpose: The purpose of the example, e.g. to illustrate a scenario
    :param Actor actor: Actor participating in the resource
    :param Instance instance: Each resource and each version that is present in the workflow
    :param Process process: Each major process - a group of operations
    :param str workflow: Another nested workflow
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "contact": {"class_name": "ContactDetail", "is_contained": False},
        "useContext": {"class_name": "UsageContext", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
        "actor": {"class_name": "Actor", "is_contained": True},
        "instance": {"class_name": "Instance", "is_contained": True},
        "process": {"class_name": "Process", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        url: "str" = None,
        identifier: list["Identifier"] = None,
        version: "str" = None,
        name: "str" = None,
        status: "str" = None,
        experimental: "bool" = None,
        date: "str" = None,
        publisher: "str" = None,
        contact: list["ContactDetail"] = None,
        useContext: list["UsageContext"] = None,
        jurisdiction: list["CodeableConcept"] = None,
        copyright: "str" = None,
        purpose: "str" = None,
        actor: list["Actor"] = None,
        instance: list["Instance"] = None,
        process: list["Process"] = None,
        workflow: list["str"] = None,
    ):

        self.resourceType = "ExampleScenario"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.url = url
        self.identifier = identifier or []
        self.version = version
        self.name = name
        self.status = status
        self.experimental = experimental
        self.date = date
        self.publisher = publisher
        self.contact = contact or []
        self.useContext = useContext or []
        self.jurisdiction = jurisdiction or []
        self.copyright = copyright
        self.purpose = purpose
        self.actor = actor or []
        self.instance = instance or []
        self.process = process or []
        self.workflow = workflow or []

    @classmethod
    def from_dict(cls, data: dict) -> "ExampleScenario":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ExampleScenario":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Timing. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.Duration import *
from fhirmodels.R4.Element import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Period import *
from fhirmodels.R4.Range import *


class Repeat(FhirBaseModel):
    """A set of rules that describe when the event is scheduled.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Duration boundsDuration: Length/Range of lengths, or (Start and/or end) limits
    :param Range boundsRange: Length/Range of lengths, or (Start and/or end) limits
    :param Period boundsPeriod: Length/Range of lengths, or (Start and/or end) limits
    :param int count: Number of times to repeat
    :param int countMax: Maximum number of times to repeat
    :param float duration: How long when it happens
    :param float durationMax: How long when it happens (Max)
    :param str durationUnit: s | min | h | d | wk | mo | a - unit of time (UCUM)
    :param int frequency: Event occurs frequency times per period
    :param int frequencyMax: Event occurs up to frequencyMax times per period
    :param float period: Event occurs frequency times per period
    :param float periodMax: Upper limit of period (3-4 hours)
    :param str periodUnit: s | min | h | d | wk | mo | a - unit of time (UCUM)
    :param str dayOfWeek: mon | tue | wed | thu | fri | sat | sun
    :param str timeOfDay: Time of day for action
    :param str when: Code for time period of occurrence
    :param int offset: Minutes from event (before or after)
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "boundsDuration": {"class_name": "Duration", "is_contained": False},
        "boundsRange": {"class_name": "Range", "is_contained": False},
        "boundsPeriod": {"class_name": "Period", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        boundsDuration: "Duration" = None,
        boundsRange: "Range" = None,
        boundsPeriod: "Period" = None,
        count: "int" = None,
        countMax: "int" = None,
        duration: "float" = None,
        durationMax: "float" = None,
        durationUnit: "str" = None,
        frequency: "int" = None,
        frequencyMax: "int" = None,
        period: "float" = None,
        periodMax: "float" = None,
        periodUnit: "str" = None,
        dayOfWeek: list["str"] = None,
        timeOfDay: list["str"] = None,
        when: list["str"] = None,
        offset: "int" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.boundsDuration = boundsDuration
        self.boundsRange = boundsRange
        self.boundsPeriod = boundsPeriod
        self.count = count
        self.countMax = countMax
        self.duration = duration
        self.durationMax = durationMax
        self.durationUnit = durationUnit
        self.frequency = frequency
        self.frequencyMax = frequencyMax
        self.period = period
        self.periodMax = periodMax
        self.periodUnit = periodUnit
        self.dayOfWeek = dayOfWeek or []
        self.timeOfDay = timeOfDay or []
        self.when = when or []
        self.offset = offset

    @classmethod
    def from_dict(cls, data: dict) -> "Timing":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Timing":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Timing(FhirBaseModel):
    """Base StructureDefinition for Timing Type: Specifies an event that may occur multiple times. Timing schedules are used to record when things are planned, expected or requested to occur. The most common usage is in dosage instructions for medications. They are also used when planning care of various kinds, and may be used for reporting the schedule to which past regular activities were carried out.
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str event: When the event occurs
    :param Repeat repeat: When the event is to occur
    :param CodeableConcept code: BID | TID | QID | AM | PM | QD | QOD | +
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "repeat": {"class_name": "Repeat", "is_contained": True},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        event: list["str"] = None,
        repeat: "Repeat" = None,
        code: "CodeableConcept" = None,
    ):

        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.event = event or []
        self.repeat = repeat
        self.code = code

    @classmethod
    def from_dict(cls, data: dict) -> "Timing":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Timing":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Communication. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.Annotation import *
from fhirmodels.R4.Attachment import *
from fhirmodels.R4.BackboneElement import *
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Identifier import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.Reference import *
from fhirmodels.R4.Resource import *


class Payload(FhirBaseModel):
    """Text, attachment(s), or resource(s) that was communicated to the recipient.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str contentString: Message part content
    :param Attachment contentAttachment: Message part content
    :param Reference contentReference: Message part content
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "contentAttachment": {"class_name": "Attachment", "is_contained": False},
        "contentReference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        contentString: "str" = None,
        contentAttachment: "Attachment" = None,
        contentReference: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.contentString = contentString
        self.contentAttachment = contentAttachment
        self.contentReference = contentReference

    @classmethod
    def from_dict(cls, data: dict) -> "Communication":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Communication":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Communication(DomainResource):
    """An occurrence of information being transmitted; e.g. an alert that was sent to a responsible provider, a public health agency that was notified about a reportable condition.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Unique identifier
    :param str instantiatesCanonical: Instantiates FHIR protocol or definition
    :param str instantiatesUri: Instantiates external protocol or definition
    :param Reference basedOn: Request fulfilled by this communication
    :param Reference partOf: Part of this action
    :param Reference inResponseTo: Reply to
    :param str status: preparation | in-progress | not-done | on-hold | stopped | completed | entered-in-error | unknown
    :param CodeableConcept statusReason: Reason for current status
    :param CodeableConcept category: Message category
    :param str priority: routine | urgent | asap | stat
    :param CodeableConcept medium: A channel of communication
    :param Reference subject: Focus of message
    :param CodeableConcept topic: Description of the purpose/content
    :param Reference about: Resources that pertain to this communication
    :param Reference encounter: Encounter created as part of
    :param str sent: When sent
    :param str received: When received
    :param Reference recipient: Message recipient
    :param Reference sender: Message sender
    :param CodeableConcept reasonCode: Indication for message
    :param Reference reasonReference: Why was communication done?
    :param Payload payload: Message payload
    :param Annotation note: Comments made about the communication
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "basedOn": {"class_name": "Reference", "is_contained": False},
        "partOf": {"class_name": "Reference", "is_contained": False},
        "inResponseTo": {"class_name": "Reference", "is_contained": False},
        "statusReason": {"class_name": "CodeableConcept", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "medium": {"class_name": "CodeableConcept", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "topic": {"class_name": "CodeableConcept", "is_contained": False},
        "about": {"class_name": "Reference", "is_contained": False},
        "encounter": {"class_name": "Reference", "is_contained": False},
        "recipient": {"class_name": "Reference", "is_contained": False},
        "sender": {"class_name": "Reference", "is_contained": False},
        "reasonCode": {"class_name": "CodeableConcept", "is_contained": False},
        "reasonReference": {"class_name": "Reference", "is_contained": False},
        "payload": {"class_name": "Payload", "is_contained": True},
        "note": {"class_name": "Annotation", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        instantiatesCanonical: list["str"] = None,
        instantiatesUri: list["str"] = None,
        basedOn: list["Reference"] = None,
        partOf: list["Reference"] = None,
        inResponseTo: list["Reference"] = None,
        status: "str" = None,
        statusReason: "CodeableConcept" = None,
        category: list["CodeableConcept"] = None,
        priority: "str" = None,
        medium: list["CodeableConcept"] = None,
        subject: "Reference" = None,
        topic: "CodeableConcept" = None,
        about: list["Reference"] = None,
        encounter: "Reference" = None,
        sent: "str" = None,
        received: "str" = None,
        recipient: list["Reference"] = None,
        sender: "Reference" = None,
        reasonCode: list["CodeableConcept"] = None,
        reasonReference: list["Reference"] = None,
        payload: list["Payload"] = None,
        note: list["Annotation"] = None,
    ):

        self.resourceType = "Communication"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.instantiatesCanonical = instantiatesCanonical or []
        self.instantiatesUri = instantiatesUri or []
        self.basedOn = basedOn or []
        self.partOf = partOf or []
        self.inResponseTo = inResponseTo or []
        self.status = status
        self.statusReason = statusReason
        self.category = category or []
        self.priority = priority
        self.medium = medium or []
        self.subject = subject
        self.topic = topic
        self.about = about or []
        self.encounter = encounter
        self.sent = sent
        self.received = received
        self.recipient = recipient or []
        self.sender = sender
        self.reasonCode = reasonCode or []
        self.reasonReference = reasonReference or []
        self.payload = payload or []
        self.note = note or []

    @classmethod
    def from_dict(cls, data: dict) -> "Communication":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Communication":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()
